@@ -888,9 +888,6 @@ static inline void glTranslatev(const GLvector *v)
     MATRIX_TRANSLATE = v->z;
 }
 
-// Map old name to new name
-#define glTranslate3f32 glTranslatef32
-
 /// Multiply the current matrix by a translation matrix.
 ///
 /// @param x
@@ -906,6 +903,21 @@ static inline void glTranslatef32(int x, int y, int z)
     MATRIX_TRANSLATE = z;
 }
 
+/// Multiply the current matrix by a translation matrix.
+///
+/// Alias of glTranslatef32().
+///
+/// @param x
+///     Translation on the x axis.
+/// @param y
+///     Translation on the y axis.
+/// @param z
+///     Translation on the z axis.
+static inline void glTranslate3f32(int x, int y, int z)
+{
+    glTranslatef32(x, y, z);
+}
+
 /// Multiply the current matrix by a scale matrix.
 ///
 /// @param x
