@@ -22,6 +22,7 @@ extern "C" {
 
 #include <stddef.h>
 
+#include <nds/fifocommon.h>
 #include <nds/ndstypes.h>
 
 /// Screen height in pixels.
@@ -330,7 +331,15 @@ static inline void lcdMainOnBottom(void)
 /// Powers down the DS
 static inline void systemShutDown(void)
 {
-    powerOn(PM_SYSTEM_PWR);
+    fifoSendValue32(FIFO_PM, PM_REQ_SHUTDOWN);
+}
+
+/// This function reboots the console.
+///
+/// It only works on DSi. On DS it does nothing.
+static inline void systemReboot(void)
+{
+    fifoSendValue32(FIFO_PM, PM_REQ_REBOOT);
 }
 
 /// Set the ARM9 interrupt vector base to one of two locations:
@@ -406,7 +415,6 @@ bool setCpuClock(bool speed);
 
 #ifdef ARM7
 
-#define REG_CID              ((vu8 *)0x02FFD7BC)
 #define REG_CONSOLEID        (*(vu64 *)0x04004D00)
 #define REG_CONSOLEID_FLAG   (*(vu16 *)0x04004D08)
 
@@ -426,22 +434,27 @@ u64 getConsoleID(void);
 ///     up these hardware devices via the ARM9 would lead to unexpected results.
 ///     ARM7 only.
 typedef enum {
-    POWER_SOUND = BIT(0),          ///< Controls the power for the sound controller
-    POWER_WIFI  = BIT(1),          ///< Controls the power for the WiFi controller
+    POWER_SOUND = BIT(0), ///< Controls the power for the sound controller
+    POWER_WIFI  = BIT(1), ///< Controls the power for the WiFi controller
 
-    PM_CONTROL_REG     = 0,        ///< Selects the PM control register
-    PM_BATTERY_REG     = 1,        ///< Selects the PM battery register
-    PM_AMPLIFIER_REG   = 2,        ///< Selects the PM amplifier register
-    PM_READ_REGISTER   = (1 << 7), ///< Selects the PM read register
-    PM_AMP_OFFSET      = 2,        ///< Selects the PM amp register
-    PM_GAIN_OFFSET     = 3,        ///< Selects the PM gain register
-    PM_BACKLIGHT_LEVEL = 4,        ///< Selects the DS Lite backlight register
-    PM_GAIN_20         = 0,        ///< Sets the mic gain to 20db
-    PM_GAIN_40         = 1,        ///< Sets the mic gain to 40db
-    PM_GAIN_80         = 2,        ///< Sets the mic gain to 80db
-    PM_GAIN_160        = 3,        ///< Sets the mic gain to 160db
-    PM_AMP_ON          = 1,        ///< Turns the sound amp ON
-    PM_AMP_OFF         = 0         ///< Turns the sound amp OFF
+    PM_WRITE_REGISTER  = (0 << 7), ///< Selects PM write operation
+    PM_READ_REGISTER   = (1 << 7), ///< Selects PM read operation
+
+    PM_CONTROL_REG     = 0,     ///< Selects the PM control register
+    PM_BATTERY_REG     = 1,     ///< Selects the PM battery register
+    PM_AMPLIFIER_REG   = 2,     ///< Selects the PM amplifier register
+    PM_AMP_OFFSET      = PM_AMPLIFIER_REG, ///< Alias of PM_AMPLIFIER_REG
+    PM_GAIN_OFFSET     = 3,     ///< Selects the PM gain register
+    PM_BACKLIGHT_LEVEL = 4,     ///< Selects the DS Lite backlight register
+    PM_DSI_RESET_REG   = 0x10,  ///< Selects the DSi backlight mirror and reset register
+
+    PM_GAIN_20  = 0, ///< Sets the mic gain to 20db
+    PM_GAIN_40  = 1, ///< Sets the mic gain to 40db
+    PM_GAIN_80  = 2, ///< Sets the mic gain to 80db
+    PM_GAIN_160 = 3, ///< Sets the mic gain to 160db
+
+    PM_AMP_ON   = 1, ///< Turns the sound amp ON
+    PM_AMP_OFF  = 0  ///< Turns the sound amp OFF
 } ARM7_power;
 
 /// PM control register bits - LED control
@@ -497,9 +510,16 @@ static inline void powerOff(uint32_t bits)
 ///     It returns true on success, false on error.
 bool readUserSettings(void);
 
-/// This function shutds down the console.
+/// This function shuts down the console.
+///
+/// If it fails, it returns.
 void systemShutDown(void);
 
+/// This function reboots the console.
+///
+/// It only works on DSi. On DS it does nothing.
+void systemReboot(void);
+
 #endif // ARM7
 
 /// DS-Lite firmware backlight level settings.
